render

Function render 

pub fn render(
    error: &Error,
    sources: &Sources,
    file: FileId,
    mode: BacktraceMode,
) -> Option<String>
Render the backtrace against sources. file is the entrypoint script; the registry may also include package sources whose DWARF paths can render source context for package frames.