pub fn typecheck(
source: &str,
file: FileId,
) -> Result<Vec<Diagnostic>, Vec<Diagnostic>>Expand description
Compatibility adapter returning source and fatal failures as diagnostics.
pub fn typecheck(
source: &str,
file: FileId,
) -> Result<Vec<Diagnostic>, Vec<Diagnostic>>Compatibility adapter returning source and fatal failures as diagnostics.