pub fn bounded_text(
text: &str,
bytes: usize,
) -> Result<RenderedText, RenderError>Expand description
Bound a retained diagnostic field before copying it into a response.
pub fn bounded_text(
text: &str,
bytes: usize,
) -> Result<RenderedText, RenderError>Bound a retained diagnostic field before copying it into a response.