pub struct TypedSwitchCase {
pub values: Vec<TypedSwitchValue>,
pub body: StmtId,
pub span: Span,
}Expand description
Multiple entries in values when consecutive case labels share a body.
body is wrapped in NarrowRegion by the inferer for discriminated unions.
Fields
values: Vec<TypedSwitchValue>body: StmtIdspan: SpanImplementations
Sourceimpl TypedSwitchCase
impl TypedSwitchCase
Sourcepub fn label_comparisons(&self) -> impl Iterator<Item = ExprId> + '_
pub fn label_comparisons(&self) -> impl Iterator<Item = ExprId> + '_
The run-time comparisons of the clause’s labels that aren’t literals, which run before any clause body does.